@@ -23,40 +23,15 @@ Enum subclasses with some extra features
 #  MA 02110-1301, USA.
 #
 
+# stdlib
+import warnings
+
 # 3rd party
-from aenum import Enum, IntEnum  # type: ignore
+from enum_tools import IntEnum, StrEnum
 
 __all__ = ["IntEnum", "StrEnum"]
 
-# class IntEnum(Enum):
-# 	"""
-# 	An Enum that can be converted into an integer.
-# 	"""
-#
-# 	def __int__(self):
-# 		return self.value
-#
-# 	def __eq__(self, other):
-# 		if int(self) == other:
-# 			return True
-# 		else:
-# 			return super().__eq__(other)
-
-
-class StrEnum(str, Enum):
-	"""
-	An Enum that can be converted into a string.
-	"""
-
-	def __str__(self) -> str:
-		return self.value
-
-	#
-	# def __repr__(self):
-	# 	return self.value
-
-	# def __eq__(self, other):
-	# 	if str(self) == other:
-	# 		return True
-	# 	else:
-	# 		return super().__eq__(other)
+warnings.warn(
+		"Importing enums from domdf_python_tools.enums is deprecated since 0.4.10 "
+		"and the module will be removed in 0.5.0. Import from the enum_tools library instead."
+		)
