@@ -67,9 +67,17 @@ import pprint
 import shlex
 import struct
 import subprocess
-import sys
 import textwrap
-from typing import Optional, Tuple
+from typing import Any, Optional, Tuple
+
+__all__ = [
+		"clear",
+		"br",
+		"interrupt",
+		"overtype",
+		"get_terminal_size",
+		"Echo",
+		]
 
 
 def clear() -> None:
@@ -80,7 +88,7 @@ def clear() -> None:
 	"""
 
 	if os.name == "nt":  # pragma: no cover (!Windows)
-		os.system("cls")
+		os.system("cls")  # nosec: B607,B605
 	else:  # pragma: no cover (!Linux)
 		print("\033c", end='')
 
@@ -185,7 +193,7 @@ def _get_terminal_size_windows() -> Optional[Tuple[int, int]]:  # pragma: no cov
 			size_y = bottom - top + 1
 
 			return size_x, size_y
-	except:
+	except Exception:
 		pass
 
 	return None
@@ -198,7 +206,7 @@ def _get_terminal_size_tput() -> Optional[Tuple[int, int]]:  # pragma: no cover
 		cols = int(subprocess.check_call(shlex.split("tput cols")))
 		rows = int(subprocess.check_call(shlex.split("tput lines")))
 		return cols, rows
-	except:
+	except Exception:
 		return None
 
 
@@ -208,13 +216,15 @@ def _get_terminal_size_posix() -> Optional[Tuple[int, int]]:  # pragma: no cover
 	import fcntl
 	import termios
 
-	def ioctl_GWINSZ(fd):
+	def ioctl_GWINSZ(fd: int) -> Optional[Tuple[Any, ...]]:
 		try:
-			cr = struct.unpack("hh", fcntl.ioctl(fd, termios.TIOCGWINSZ, "1234"))
+			cr = struct.unpack("hh", fcntl.ioctl(fd, termios.TIOCGWINSZ, b"1234"))
 			return cr
-		except:
+		except Exception:
 			pass
 
+		return None
+
 	cr = ioctl_GWINSZ(0) or ioctl_GWINSZ(1) or ioctl_GWINSZ(2)
 
 	if not cr:
@@ -222,13 +232,13 @@ def _get_terminal_size_posix() -> Optional[Tuple[int, int]]:  # pragma: no cover
 			fd = os.open(os.ctermid(), os.O_RDONLY)  # type: ignore
 			cr = ioctl_GWINSZ(fd)
 			os.close(fd)
-		except:
+		except Exception:
 			pass
 
 	if not cr:
 		try:
 			cr = (os.environ["LINES"], os.environ["COLUMNS"])
-		except:
+		except Exception:
 			return None
 
 	return int(cr[1]), int(cr[0])
@@ -252,10 +262,16 @@ class Echo:
 			self.parent_frame = inspect.currentframe().f_back  # type: ignore  # TODO
 
 	def __enter__(self):
-		self.locals_on_entry = self.parent_frame.f_locals.copy()
+		self.locals_on_entry = self.parent_frame.f_locals.copy()  # type: ignore
 
 	def __exit__(self, exc_t, exc_v, tb):
-		new_locals = {k: v for k, v in self.parent_frame.f_locals.items() if k not in self.locals_on_entry}
+		new_locals = {
+				k: v
+				for k,
+				v in self.parent_frame.f_locals.items()  # type: ignore
+				if k not in self.locals_on_entry
+				}
+
 		print(textwrap.indent(pprint.pformat(new_locals), self.indent))
 
 
